summaryrefslogtreecommitdiff
path: root/django
diff options
context:
space:
mode:
Diffstat (limited to 'django')
-rw-r--r--django/core/management/commands/flush.py10
1 files changed, 7 insertions, 3 deletions
diff --git a/django/core/management/commands/flush.py b/django/core/management/commands/flush.py
index 637d6d525b..bad80c2e0b 100644
--- a/django/core/management/commands/flush.py
+++ b/django/core/management/commands/flush.py
@@ -84,9 +84,13 @@ Are you sure you want to do this?
# Reinstall the initial_data fixture.
if options.get('load_initial_data'):
- # Reinstall the initial_data fixture.
- call_command('loaddata', 'initial_data', **options)
-
+ # Reinstall the initial_data fixture for apps without migrations.
+ from django.db.migrations.executor import MigrationExecutor
+ executor = MigrationExecutor(connection)
+ app_options = options.copy()
+ for app_label in executor.loader.unmigrated_apps:
+ app_options['app_label'] = app_label
+ call_command('loaddata', 'initial_data', **app_options)
else:
self.stdout.write("Flush cancelled.\n")